@@ -22,9 +22,11 @@ Self-hosted runners in AWS are useful when:
 * You want to pre-install some software for your actions
 * You want to provide some basic AWS API access ([aws-actions/configure-aws-credentials](https://github.com/marketplace/actions/configure-aws-credentials-action-for-github-actions) has more security controls)
 
+Ephemeral runners are the [recommended way by GitHub](https://docs.github.com/en/actions/hosting-your-own-runners/autoscaling-with-self-hosted-runners#using-ephemeral-runners-for-autoscaling) for auto-scaling, and they make sure all jobs run with a clean image. Runners are started on-demand. You don't pay unless a job is running.
+
 ## API
 
-See [API.md](API.md) for full interface documentation.
+Documentation of available constructs and their interface is available on [Constructs Hub](https://constructs.dev/packages/@cloudsnorkel/cdk-github-runners/) in all supported programming languages.
 
 ## Providers
 
@@ -33,12 +35,12 @@ A runner provider creates compute resources on-demand and uses [actions/runner](
 | Provider  | Time limit               | vCPUs                    | RAM                               | Storage                      | sudo | Docker |
 |-----------|--------------------------|--------------------------|-----------------------------------|------------------------------|------|--------|
 | CodeBuild | 8 hours (default 1 hour) | 2 (default), 4, 8, or 72 | 3gb (default), 7gb, 15gb or 145gb | 50gb to 824gb (default 64gb) | ✔    | ✔     |
-| Fargate   | Unlimited                | 0.25 to 4 (default 1)    | 512mb to 30gb (default 2gb)       | 20gb to 200gb (default 25gb) | ✔    | TBD    |
+| Fargate   | Unlimited                | 0.25 to 4 (default 1)    | 512mb to 30gb (default 2gb)       | 20gb to 200gb (default 25gb) | ✔    | ❌    |
 | Lambda    | 15 minutes               | 1 to 6 (default 2)       | 128mb to 10gb (default 2gb)       | Up to 10gb (default 10gb)    | ❌    | ❌     |
 
 The best provider to use mostly depends on your current infrastructure. When in doubt, CodeBuild is always a good choice. Execution history and logs are easy to view, and it has no restrictive limits unless you need to run for more than 8 hours.
 
-You can also create your own provider by implementing [`IRunnerProvider`](API.md#IRunnerProvider).
+You can also create your own provider by implementing `IRunnerProvider`.
 
 ## Installation
 
@@ -73,7 +75,7 @@ You can also create your own provider by implementing [`IRunnerProvider`](API.md
       ```
       dotnet add package CloudSnorkel.Cdk.Github.Runners
       ```
-3. Use [`GitHubRunners`](API.md#CodeBuildRunner) construct in your code (starting with defaults is fine)
+3. Use `GitHubRunners` construct in your code (starting with default arguments is fine)
 4. Deploy your stack
 5. Look for the status command output similar to `aws --region us-east-1 lambda invoke --function-name status-XYZ123 status.json`
 6. Execute the status command (you may need to specify `--profile` too) and open the resulting `status.json` file
@@ -84,7 +86,7 @@ You can also create your own provider by implementing [`IRunnerProvider`](API.md
 
 ## Customizing
 
-The default providers configured by [`GitHubRunners`](API.md#CodeBuildRunner) are useful for testing but probably not too much for actual production work. They run in the default VPC or no VPC and have no added IAM permissions. You would usually want to configure the providers yourself.
+The default providers configured by [`GitHubRunners`](https://constructs.dev/packages/@cloudsnorkel/cdk-github-runners/v/0.0.11/api/GitHubRunners?lang=typescript) are useful for testing but probably not too much for actual production work. They run in the default VPC or no VPC and have no added IAM permissions. You would usually want to configure the providers yourself.
 
 For example:
 
@@ -186,7 +188,44 @@ class GitHubRunners(
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudsnorkel/cdk-github-runners.GitHubRunners",
 ):
-    '''
+    '''(experimental) Create all the required infrastructure to provide self-hosted GitHub runners.
+
+    It creates a webhook, secrets, and a step function to orchestrate all runs. Secrets are not automatically filled. See README.md for instructions on how to setup GitHub integration.
+
+    By default, this will create a runner provider of each available type with the defaults. This is good enough for the initial setup stage when you just want to get GitHub integration working::
+
+       new GitHubRunners(stack, 'runners', {});
+
+    Usually you'd want to configure the runner providers so the runners can run in a certain VPC or have certain permissions::
+
+       const vpc = ec2.Vpc.fromLookup(stack, 'vpc', { vpcId: 'vpc-1234567' });
+       const runnerSg = new ec2.SecurityGroup(stack, 'runner security group', { vpc: vpc });
+       const dbSg = ec2.SecurityGroup.fromSecurityGroupId(stack, 'database security group', 'sg-1234567');
+       const bucket = new s3.Bucket(stack, 'runner bucket');
+
+       // create a custom CodeBuild provider
+       const myProvider = new CodeBuildRunner(
+          stack, 'codebuild runner',
+          {
+             label: 'my-codebuild',
+             vpc: vpc,
+             securityGroup: runnerSg,
+          },
+       );
+       // grant some permissions to the provider
+       bucket.grantReadWrite(myProvider);
+       dbSg.connections.allowFrom(runnerSg, ec2.Port.tcp(3306), 'allow runners to connect to MySQL database');
+
+       // create the runner infrastructure
+       new GitHubRunners(
+          stack,
+          'runners',
+          {
+            providers: [myProvider],
+            defaultProviderLabel: 'my-codebuild',
+          }
+       );
+
     :stability: experimental
     '''
 
@@ -201,8 +240,8 @@ class GitHubRunners(
         '''
         :param scope: -
         :param id: -
-        :param default_provider_label: 
-        :param providers: 
+        :param default_provider_label: (experimental) Label of default provider in case the workflow job doesn't specify any known label. A provider with that label must be configured. Default: 'codebuild'
+        :param providers: (experimental) List of runner providers to use. At least one provider is required. Provider will be selected when its label matches the labels requested by the workflow job. Default: CodeBuild, Lambda and Fargate runners with all the defaults (no VPC or default account VPC)
 
         :stability: experimental
         '''
@@ -215,7 +254,8 @@ class GitHubRunners(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="defaultProvider")
     def default_provider(self) -> "IRunnerProvider":
-        '''
+        '''(experimental) Default provider as set by {@link GitHubRunnersProps.defaultProviderLabel}.
+
         :stability: experimental
         '''
         return typing.cast("IRunnerProvider", jsii.get(self, "defaultProvider"))
@@ -231,7 +271,8 @@ class GitHubRunners(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="providers")
     def providers(self) -> typing.List["IRunnerProvider"]:
-        '''
+        '''(experimental) Configured runner providers.
+
         :stability: experimental
         '''
         return typing.cast(typing.List["IRunnerProvider"], jsii.get(self, "providers"))
@@ -239,7 +280,8 @@ class GitHubRunners(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="secrets")
     def secrets(self) -> "Secrets":
-        '''
+        '''(experimental) Secrets for GitHub communication including webhook secret and runner authentication.
+
         :stability: experimental
         '''
         return typing.cast("Secrets", jsii.get(self, "secrets"))
@@ -260,10 +302,10 @@ class GitHubRunnersProps:
         default_provider_label: typing.Optional[builtins.str] = None,
         providers: typing.Optional[typing.Sequence["IRunnerProvider"]] = None,
     ) -> None:
-        '''(experimental) Properties of the GitHubRunners.
+        '''(experimental) Properties for GitHubRunners.
 
-        :param default_provider_label: 
-        :param providers: 
+        :param default_provider_label: (experimental) Label of default provider in case the workflow job doesn't specify any known label. A provider with that label must be configured. Default: 'codebuild'
+        :param providers: (experimental) List of runner providers to use. At least one provider is required. Provider will be selected when its label matches the labels requested by the workflow job. Default: CodeBuild, Lambda and Fargate runners with all the defaults (no VPC or default account VPC)
 
         :stability: experimental
         '''
@@ -275,7 +317,12 @@ class GitHubRunnersProps:
 
     @builtins.property
     def default_provider_label(self) -> typing.Optional[builtins.str]:
-        '''
+        '''(experimental) Label of default provider in case the workflow job doesn't specify any known label.
+
+        A provider with that label must be configured.
+
+        :default: 'codebuild'
+
         :stability: experimental
         '''
         result = self._values.get("default_provider_label")
@@ -283,7 +330,12 @@ class GitHubRunnersProps:
 
     @builtins.property
     def providers(self) -> typing.Optional[typing.List["IRunnerProvider"]]:
-        '''
+        '''(experimental) List of runner providers to use.
+
+        At least one provider is required. Provider will be selected when its label matches the labels requested by the workflow job.
+
+        :default: CodeBuild, Lambda and Fargate runners with all the defaults (no VPC or default account VPC)
+
         :stability: experimental
         '''
         result = self._values.get("providers")
@@ -307,7 +359,10 @@ class IRunnerProvider(
     aws_cdk.aws_iam.IGrantable,
     typing_extensions.Protocol,
 ):
-    '''
+    '''(experimental) Interface for all runner providers.
+
+    Implementations create all required resources and return a step function task that starts those resources from {@link getStepFunctionTask}.
+
     :stability: experimental
     '''
 
@@ -350,11 +405,13 @@ class IRunnerProvider(
     ) -> aws_cdk.aws_stepfunctions.IChainable:
         '''(experimental) Generate step function tasks that execute the runner.
 
-        :param github_domain_path: 
-        :param owner_path: 
-        :param repo_path: 
-        :param runner_name_path: 
-        :param runner_token_path: 
+        Called by GithubRunners and shouldn't be called manually.
+
+        :param github_domain_path: (experimental) Path to GitHub domain. Most of the time this will be github.com but for self-hosted GitHub instances, this will be different.
+        :param owner_path: (experimental) Path to repostiroy owner name.
+        :param repo_path: (experimental) Path to repository name.
+        :param runner_name_path: (experimental) Path to desired runner name. We specifically set the name to make troubleshooting easier.
+        :param runner_token_path: (experimental) Path to runner token used to register token.
 
         :stability: experimental
         '''
@@ -365,7 +422,10 @@ class _IRunnerProviderProxy(
     jsii.proxy_for(aws_cdk.aws_ec2.IConnectable), # type: ignore[misc]
     jsii.proxy_for(aws_cdk.aws_iam.IGrantable), # type: ignore[misc]
 ):
-    '''
+    '''(experimental) Interface for all runner providers.
+
+    Implementations create all required resources and return a step function task that starts those resources from {@link getStepFunctionTask}.
+
     :stability: experimental
     '''
 
@@ -410,11 +470,13 @@ class _IRunnerProviderProxy(
     ) -> aws_cdk.aws_stepfunctions.IChainable:
         '''(experimental) Generate step function tasks that execute the runner.
 
-        :param github_domain_path: 
-        :param owner_path: 
-        :param repo_path: 
-        :param runner_name_path: 
-        :param runner_token_path: 
+        Called by GithubRunners and shouldn't be called manually.
+
+        :param github_domain_path: (experimental) Path to GitHub domain. Most of the time this will be github.com but for self-hosted GitHub instances, this will be different.
+        :param owner_path: (experimental) Path to repostiroy owner name.
+        :param repo_path: (experimental) Path to repository name.
+        :param runner_name_path: (experimental) Path to desired runner name. We specifically set the name to make troubleshooting easier.
+        :param runner_token_path: (experimental) Path to runner token used to register token.
 
         :stability: experimental
         '''
@@ -442,6 +504,8 @@ class LambdaRunner(
 
     Creates a Docker-based function that gets executed for each job.
 
+    This construct is not meant to be used by itself. It should be passed in the providers property for GitHubRunners.
+
     :stability: experimental
     '''
 
@@ -499,13 +563,15 @@ class LambdaRunner(
         runner_name_path: builtins.str,
         runner_token_path: builtins.str,
     ) -> aws_cdk.aws_stepfunctions.IChainable:
-        '''(experimental) Generate step function tasks that execute the runner.
+        '''(experimental) Generate step function task(s) to start a new runner.
 
-        :param github_domain_path: 
-        :param owner_path: 
-        :param repo_path: 
-        :param runner_name_path: 
-        :param runner_token_path: 
+        Called by GithubRunners and shouldn't be called manually.
+
+        :param github_domain_path: (experimental) Path to GitHub domain. Most of the time this will be github.com but for self-hosted GitHub instances, this will be different.
+        :param owner_path: (experimental) Path to repostiroy owner name.
+        :param repo_path: (experimental) Path to repository name.
+        :param runner_name_path: (experimental) Path to desired runner name. We specifically set the name to make troubleshooting easier.
+        :param runner_token_path: (experimental) Path to runner token used to register token.
 
         :stability: experimental
         '''
@@ -531,7 +597,8 @@ class LambdaRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="function")
     def function(self) -> aws_cdk.aws_lambda.Function:
-        '''
+        '''(experimental) The function hosting the GitHub runner.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "function"))
@@ -539,7 +606,7 @@ class LambdaRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="grantPrincipal")
     def grant_principal(self) -> aws_cdk.aws_iam.IPrincipal:
-        '''(experimental) The principal to grant permissions to.
+        '''(experimental) Grant principal used to add permissions to the runner role.
 
         :stability: experimental
         '''
@@ -548,7 +615,7 @@ class LambdaRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="label")
     def label(self) -> builtins.str:
-        '''(experimental) GitHub Actions label associated with this runner provider.
+        '''(experimental) Label associated with this provider.
 
         :stability: experimental
         '''
@@ -557,7 +624,7 @@ class LambdaRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="securityGroup")
     def security_group(self) -> typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]:
-        '''(experimental) Security group associated with runners.
+        '''(experimental) Security group attached to the function.
 
         :stability: experimental
         '''
@@ -566,7 +633,7 @@ class LambdaRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
-        '''(experimental) VPC network in which runners will be placed.
+        '''(experimental) VPC used for hosting the function.
 
         :stability: experimental
         '''
@@ -585,7 +652,8 @@ class RunnerProviderProps:
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
         runner_version: typing.Optional["RunnerVersion"] = None,
     ) -> None:
-        '''
+        '''(experimental) Common properties for all runner providers.
+
         :param log_retention: (experimental) The number of days log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.ONE_MONTH
         :param runner_version: (experimental) Version of GitHub Runners to install. Default: latest version available
 
@@ -656,12 +724,19 @@ class RunnerRuntimeParameters:
         runner_name_path: builtins.str,
         runner_token_path: builtins.str,
     ) -> None:
-        '''
-        :param github_domain_path: 
-        :param owner_path: 
-        :param repo_path: 
-        :param runner_name_path: 
-        :param runner_token_path: 
+        '''(experimental) Workflow job parameters as parsed from the webhook event. Pass these into your runner executor and run something like:.
+
+        Example::
+
+           ./config.sh --unattended --url "https://${GITHUB_DOMAIN}/${OWNER}/${REPO}" --token "${RUNNER_TOKEN}" --ephemeral --work _work --labels "${RUNNER_LABEL}" --name "${RUNNER_NAME}" --disableupdate
+
+        All parameters are specified as step function paths and therefore must be used only in step function task parameters.
+
+        :param github_domain_path: (experimental) Path to GitHub domain. Most of the time this will be github.com but for self-hosted GitHub instances, this will be different.
+        :param owner_path: (experimental) Path to repostiroy owner name.
+        :param repo_path: (experimental) Path to repository name.
+        :param runner_name_path: (experimental) Path to desired runner name. We specifically set the name to make troubleshooting easier.
+        :param runner_token_path: (experimental) Path to runner token used to register token.
 
         :stability: experimental
         '''
@@ -675,7 +750,10 @@ class RunnerRuntimeParameters:
 
     @builtins.property
     def github_domain_path(self) -> builtins.str:
-        '''
+        '''(experimental) Path to GitHub domain.
+
+        Most of the time this will be github.com but for self-hosted GitHub instances, this will be different.
+
         :stability: experimental
         '''
         result = self._values.get("github_domain_path")
@@ -684,7 +762,8 @@ class RunnerRuntimeParameters:
 
     @builtins.property
     def owner_path(self) -> builtins.str:
-        '''
+        '''(experimental) Path to repostiroy owner name.
+
         :stability: experimental
         '''
         result = self._values.get("owner_path")
@@ -693,7 +772,8 @@ class RunnerRuntimeParameters:
 
     @builtins.property
     def repo_path(self) -> builtins.str:
-        '''
+        '''(experimental) Path to repository name.
+
         :stability: experimental
         '''
         result = self._values.get("repo_path")
@@ -702,7 +782,10 @@ class RunnerRuntimeParameters:
 
     @builtins.property
     def runner_name_path(self) -> builtins.str:
-        '''
+        '''(experimental) Path to desired runner name.
+
+        We specifically set the name to make troubleshooting easier.
+
         :stability: experimental
         '''
         result = self._values.get("runner_name_path")
@@ -711,7 +794,8 @@ class RunnerRuntimeParameters:
 
     @builtins.property
     def runner_token_path(self) -> builtins.str:
-        '''
+        '''(experimental) Path to runner token used to register token.
+
         :stability: experimental
         '''
         result = self._values.get("runner_token_path")
@@ -734,7 +818,8 @@ class RunnerVersion(
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudsnorkel/cdk-github-runners.RunnerVersion",
 ):
-    '''
+    '''(experimental) Defines desired GitHub Actions runner version.
+
     :stability: experimental
     '''
 
@@ -749,7 +834,8 @@ class RunnerVersion(
     @jsii.member(jsii_name="latest") # type: ignore[misc]
     @builtins.classmethod
     def latest(cls) -> "RunnerVersion":
-        '''
+        '''(experimental) Use the latest version available at the time the runner provider image is built.
+
         :stability: experimental
         '''
         return typing.cast("RunnerVersion", jsii.sinvoke(cls, "latest", []))
@@ -757,9 +843,11 @@ class RunnerVersion(
     @jsii.member(jsii_name="specific") # type: ignore[misc]
     @builtins.classmethod
     def specific(cls, version: builtins.str) -> "RunnerVersion":
-        '''
-        :param version: -
+        '''(experimental) Use a specific version.
 
+        :param version: GitHub Runner version.
+
+        :see: https://github.com/actions/runner/releases
         :stability: experimental
         '''
         return typing.cast("RunnerVersion", jsii.sinvoke(cls, "specific", [version]))
@@ -795,7 +883,13 @@ class Secrets(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="github")
     def github(self) -> aws_cdk.aws_secretsmanager.Secret:
-        '''
+        '''(experimental) Authentication secret for GitHub containing either app details or personal authentication token.
+
+        This secret is used to register runners and
+        cancel jobs when the runner fails to start.
+
+        This secret is meant to be edited by the user after being created.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_secretsmanager.Secret, jsii.get(self, "github"))
@@ -803,7 +897,10 @@ class Secrets(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="githubPrivateKey")
     def github_private_key(self) -> aws_cdk.aws_secretsmanager.Secret:
-        '''
+        '''(experimental) GitHub app private key. Not needed when using personal authentication tokens.
+
+        This secret is meant to be edited by the user after being created.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_secretsmanager.Secret, jsii.get(self, "githubPrivateKey"))
@@ -811,7 +908,8 @@ class Secrets(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="webhook")
     def webhook(self) -> aws_cdk.aws_secretsmanager.Secret:
-        '''
+        '''(experimental) Webhook secret used to confirm events are coming from GitHub and nowhere else.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_secretsmanager.Secret, jsii.get(self, "webhook"))
@@ -827,6 +925,8 @@ class CodeBuildRunner(
 
     Creates a project that gets started for each job.
 
+    This construct is not meant to be used by itself. It should be passed in the providers property for GitHubRunners.
+
     :stability: experimental
     '''
 
@@ -881,13 +981,15 @@ class CodeBuildRunner(
         runner_name_path: builtins.str,
         runner_token_path: builtins.str,
     ) -> aws_cdk.aws_stepfunctions.IChainable:
-        '''(experimental) Generate step function tasks that execute the runner.
+        '''(experimental) Generate step function task(s) to start a new runner.
 
-        :param github_domain_path: 
-        :param owner_path: 
-        :param repo_path: 
-        :param runner_name_path: 
-        :param runner_token_path: 
+        Called by GithubRunners and shouldn't be called manually.
+
+        :param github_domain_path: (experimental) Path to GitHub domain. Most of the time this will be github.com but for self-hosted GitHub instances, this will be different.
+        :param owner_path: (experimental) Path to repostiroy owner name.
+        :param repo_path: (experimental) Path to repository name.
+        :param runner_name_path: (experimental) Path to desired runner name. We specifically set the name to make troubleshooting easier.
+        :param runner_token_path: (experimental) Path to runner token used to register token.
 
         :stability: experimental
         '''
@@ -913,7 +1015,7 @@ class CodeBuildRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="grantPrincipal")
     def grant_principal(self) -> aws_cdk.aws_iam.IPrincipal:
-        '''(experimental) The principal to grant permissions to.
+        '''(experimental) Grant principal used to add permissions to the runner role.
 
         :stability: experimental
         '''
@@ -922,7 +1024,7 @@ class CodeBuildRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="label")
     def label(self) -> builtins.str:
-        '''(experimental) GitHub Actions label associated with this runner provider.
+        '''(experimental) Label associated with this provider.
 
         :stability: experimental
         '''
@@ -931,7 +1033,8 @@ class CodeBuildRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="project")
     def project(self) -> aws_cdk.aws_codebuild.Project:
-        '''
+        '''(experimental) CodeBuild project hosting the runner.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_codebuild.Project, jsii.get(self, "project"))
@@ -939,7 +1042,7 @@ class CodeBuildRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="securityGroup")
     def security_group(self) -> typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]:
-        '''(experimental) Security group associated with runners.
+        '''(experimental) Security group attached to the task.
 
         :stability: experimental
         '''
@@ -948,7 +1051,7 @@ class CodeBuildRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
-        '''(experimental) VPC network in which runners will be placed.
+        '''(experimental) VPC used for hosting the project.
 
         :stability: experimental
         '''
@@ -1133,6 +1236,8 @@ class FargateRunner(
 
     Creates a task definition with a single container that gets started for each job.
 
+    This construct is not meant to be used by itself. It should be passed in the providers property for GitHubRunners.
+
     :stability: experimental
     '''
 
@@ -1155,7 +1260,7 @@ class FargateRunner(
         '''
         :param scope: -
         :param id: -
-        :param assign_public_ip: (experimental) Assign public IP to the runner task. Default: true
+        :param assign_public_ip: (experimental) Assign public IP to the runner task. Make sure the task will have access to GitHub. A public IP might be required unless you have NAT gateway. Default: true
         :param cluster: (experimental) Existing Fargate cluster to use. Default: a new cluster
         :param cpu: (experimental) The number of cpu units used by the task. For tasks using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of valid values for the memory parameter: 256 (.25 vCPU) - Available memory values: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) 512 (.5 vCPU) - Available memory values: 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) 1024 (1 vCPU) - Available memory values: 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) 2048 (2 vCPU) - Available memory values: Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) 4096 (4 vCPU) - Available memory values: Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB) Default: 1024
         :param ephemeral_storage_gib: (experimental) The amount (in GiB) of ephemeral storage to be allocated to the task. The maximum supported value is 200 GiB. NOTE: This parameter is only supported for tasks hosted on AWS Fargate using platform version 1.4.0 or later. Default: 20
@@ -1193,13 +1298,15 @@ class FargateRunner(
         runner_name_path: builtins.str,
         runner_token_path: builtins.str,
     ) -> aws_cdk.aws_stepfunctions.IChainable:
-        '''(experimental) Generate step function tasks that execute the runner.
+        '''(experimental) Generate step function task(s) to start a new runner.
 
-        :param github_domain_path: 
-        :param owner_path: 
-        :param repo_path: 
-        :param runner_name_path: 
-        :param runner_token_path: 
+        Called by GithubRunners and shouldn't be called manually.
+
+        :param github_domain_path: (experimental) Path to GitHub domain. Most of the time this will be github.com but for self-hosted GitHub instances, this will be different.
+        :param owner_path: (experimental) Path to repostiroy owner name.
+        :param repo_path: (experimental) Path to repository name.
+        :param runner_name_path: (experimental) Path to desired runner name. We specifically set the name to make troubleshooting easier.
+        :param runner_token_path: (experimental) Path to runner token used to register token.
 
         :stability: experimental
         '''
@@ -1216,7 +1323,8 @@ class FargateRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="assignPublicIp")
     def assign_public_ip(self) -> builtins.bool:
-        '''
+        '''(experimental) Whether task will have a public IP.
+
         :stability: experimental
         '''
         return typing.cast(builtins.bool, jsii.get(self, "assignPublicIp"))
@@ -1224,7 +1332,8 @@ class FargateRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cluster")
     def cluster(self) -> aws_cdk.aws_ecs.Cluster:
-        '''
+        '''(experimental) Cluster hosting the task hosting the runner.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ecs.Cluster, jsii.get(self, "cluster"))
@@ -1241,7 +1350,8 @@ class FargateRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="container")
     def container(self) -> aws_cdk.aws_ecs.ContainerDefinition:
-        '''
+        '''(experimental) Container definition hosting the runner.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ecs.ContainerDefinition, jsii.get(self, "container"))
@@ -1249,7 +1359,7 @@ class FargateRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="grantPrincipal")
     def grant_principal(self) -> aws_cdk.aws_iam.IPrincipal:
-        '''(experimental) The principal to grant permissions to.
+        '''(experimental) Grant principal used to add permissions to the runner role.
 
         :stability: experimental
         '''
@@ -1258,7 +1368,7 @@ class FargateRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="label")
     def label(self) -> builtins.str:
-        '''(experimental) GitHub Actions label associated with this runner provider.
+        '''(experimental) Label associated with this provider.
 
         :stability: experimental
         '''
@@ -1267,7 +1377,8 @@ class FargateRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="task")
     def task(self) -> aws_cdk.aws_ecs.FargateTaskDefinition:
-        '''
+        '''(experimental) Fargate task hosting the runner.
+
         :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ecs.FargateTaskDefinition, jsii.get(self, "task"))
@@ -1275,7 +1386,7 @@ class FargateRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="securityGroup")
     def security_group(self) -> typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]:
-        '''(experimental) Security group associated with runners.
+        '''(experimental) Security group attached to the task.
 
         :stability: experimental
         '''
@@ -1284,7 +1395,7 @@ class FargateRunner(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
-        '''(experimental) VPC network in which runners will be placed.
+        '''(experimental) VPC used for hosting the task.
 
         :stability: experimental
         '''
@@ -1322,10 +1433,11 @@ class FargateRunnerProps(RunnerProviderProps):
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
-        '''
+        '''(experimental) Properties for FargateRunner.
+
         :param log_retention: (experimental) The number of days log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.ONE_MONTH
         :param runner_version: (experimental) Version of GitHub Runners to install. Default: latest version available
-        :param assign_public_ip: (experimental) Assign public IP to the runner task. Default: true
+        :param assign_public_ip: (experimental) Assign public IP to the runner task. Make sure the task will have access to GitHub. A public IP might be required unless you have NAT gateway. Default: true
         :param cluster: (experimental) Existing Fargate cluster to use. Default: a new cluster
         :param cpu: (experimental) The number of cpu units used by the task. For tasks using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of valid values for the memory parameter: 256 (.25 vCPU) - Available memory values: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) 512 (.5 vCPU) - Available memory values: 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) 1024 (1 vCPU) - Available memory values: 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) 2048 (2 vCPU) - Available memory values: Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) 4096 (4 vCPU) - Available memory values: Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB) Default: 1024
         :param ephemeral_storage_gib: (experimental) The amount (in GiB) of ephemeral storage to be allocated to the task. The maximum supported value is 200 GiB. NOTE: This parameter is only supported for tasks hosted on AWS Fargate using platform version 1.4.0 or later. Default: 20
@@ -1388,6 +1500,8 @@ class FargateRunnerProps(RunnerProviderProps):
     def assign_public_ip(self) -> typing.Optional[builtins.bool]:
         '''(experimental) Assign public IP to the runner task.
 
+        Make sure the task will have access to GitHub. A public IP might be required unless you have NAT gateway.
+
         :default: true
 
         :stability: experimental
